aboutsummaryrefslogtreecommitdiffstats
path: root/core/utils/utils.go
diff options
context:
space:
mode:
Diffstat (limited to 'core/utils/utils.go')
-rw-r--r--core/utils/utils.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/core/utils/utils.go b/core/utils/utils.go
index d714068..14687d6 100644
--- a/core/utils/utils.go
+++ b/core/utils/utils.go
@@ -139,8 +139,8 @@ func GetDKGThreshold(config *types.Config) int {
return int(config.DKGSetSize/3) + 1
}
-// GetNextRoundCheckpoint returns the block height to check if the next round
-// is ready.
-func GetNextRoundCheckpoint(begin, length uint64) uint64 {
+// GetNextRoundValidationHeight returns the block height to check if the next
+// round is ready.
+func GetNextRoundValidationHeight(begin, length uint64) uint64 {
return begin + length*9/10
}